@@ -13,7 +13,7 @@ _get_backend() {
 	[ -z "$eroot" ] || [ "$eroot" = "-" ] && return 1
 
 
-	backend="$(zfs-tpm-list -H "$eroot" | awk -F'\t' '{print $2}')"
+	backend="$(zfs-tpm-list -H "$eroot" | cut -f2)"
 	[ -n "$backend" ]
 	return
 }
