@@ -15,7 +15,7 @@
 
 		if [ -e /etc/tcsd.conf ]; then
 			INST_CFG /etc/tcsd.conf
-			chown tss:tss "${TARGET_DIR:-MUST_EXIST}/etc/tcsd.conf"
+			chown root:tss "${TARGET_DIR:-MUST_EXIST}/etc/tcsd.conf"
 			system_ps_file="$(awk -F '[[:space:]]*=[[:space:]]*' '!/^[[:space:]]*#/ && !/^$/ && $1 ~ /system_ps_file$/ {gsub(/[[:space:]]*$/, "", $2); print $2}' /etc/tcsd.conf)"
 			system_ps_file="${system_ps_file:-/var/lib/tpm/system.data}"
 		fi
