@@ -6,6 +6,7 @@
 #include "../zfs.hpp"
 
 #include <algorithm>
+#include <wchar.h>
 
 
 #define TZPFMS_BACKEND_MAX_LEN 16
@@ -19,8 +20,11 @@ enum class key_loadedness : char {
 
 /// zfs(8) uses struct zprop_get_cbdata_t, which is powerful, but inscrutable; we have a fixed format, which makes this easier
 struct output_line {
-	static const char * const key_available_display[2];
-	static const char * const coherent_display[2];
+	static const char * key_available_display[2];
+	static const char * coherent_display[2];
+	static uint8_t key_available_display_width[2];
+
+	static void init_display();
 
 
 	char name[ZFS_MAX_DATASET_NAME_LEN + 1];
@@ -36,8 +40,42 @@ struct output_line {
 	const char * backend_display() const { return (this->backend[0] != '\0') ? this->backend : "-"; }
 };
 
-const char * const output_line::key_available_display[2]{"unavailable", key_available_display[0] + 2};
-const char * const output_line::coherent_display[2]{"no", "yes"};
+// for KEYSTATUS column
+const char * output_line::key_available_display[2]{gettext_noop("unavailable"), gettext_noop("available")};
+// for COHERENT column
+const char * output_line::coherent_display[2]{gettext_noop("no"), gettext_noop("yes")};
+uint8_t output_line::key_available_display_width[2];
+
+
+// infallible strings only
+static int strwidth(const char * str) {
+	int ret{};
+	wchar_t c;
+	mbstate_t state{};
+	auto len = strlen(str);
+	for(;;)
+		switch(auto rd = mbrtowc(&c, str, len, &state)) {
+			case 0:          // NUL
+			case(size_t)-1:  // EILSEQ
+			case(size_t)-2:  // ENODATA
+				return ret;
+			default:
+				ret += wcwidth(c) ?: 0;
+				str += rd;
+				len -= rd;
+				break;
+		}
+}
+
+void output_line::init_display() {
+	key_available_display[false]       = gettext(key_available_display[false]);
+	key_available_display[true]        = gettext(key_available_display[true]);
+	key_available_display_width[false] = strwidth(key_available_display[false]);
+	key_available_display_width[true]  = strwidth(key_available_display[true]);
+
+	coherent_display[false] = gettext(coherent_display[false]);
+	coherent_display[true]  = gettext(coherent_display[true]);
+}
 
 
 int main(int argc, char ** argv) {
@@ -47,7 +85,7 @@ int main(int argc, char ** argv) {
 	const char * backend_restrixion = nullptr;
 	auto key_loadedness_restrixion  = key_loadedness::none;
 	return do_bare_main(
-	    argc, argv, "Hrd:ab:ul", "[-H] [-r|-d max] [-a|-b back-end] [-u|-l]", "[filesystem|volume]…",
+	    argc, argv, "Hrd:ab:ul", gettext_noop("[-H] [-r|-d max] [-a|-b back-end] [-u|-l]"), gettext_noop("[filesystem|volume]…"),
 	    [&](auto arg) {
 		    switch(arg) {
 			    case 'H':
@@ -104,35 +142,35 @@ int main(int argc, char ** argv) {
 			    return 0;
 		    }));
 
+		    output_line::init_display();
+
 		    size_t max_name_len          = 0;
 		    size_t max_backend_len       = 0;
 		    size_t max_key_available_len = 0;
-		    size_t max_coherent_len      = 0;
 		    auto separator               = "\t";
 		    if(human) {
-			    max_name_len          = strlen("NAME");
-			    max_backend_len       = strlen("BACK-END");
-			    max_key_available_len = strlen("KEYSTATUS");
-			    max_coherent_len      = strlen("COHERENT");
+			    max_name_len          = strwidth(gettext("NAME"));
+			    max_backend_len       = strwidth(gettext("BACK-END"));
+			    max_key_available_len = strwidth(gettext("KEYSTATUS"));
 			    separator             = "  ";
 
 			    for(auto cur = lines; cur != lines + lines_len; ++cur)
 				    if(cur->included(print_nontzpfms, backend_restrixion, key_loadedness_restrixion)) {
 					    max_name_len          = std::max(max_name_len, strlen(cur->name));
 					    max_backend_len       = std::max(max_backend_len, strlen(cur->backend_display()));
-					    max_key_available_len = std::max(max_key_available_len, strlen(output_line::key_available_display[cur->key_available]));
+					    max_key_available_len = std::max(max_key_available_len, static_cast<size_t>(output_line::key_available_display_width[cur->key_available]));
 				    }
 		    }
 
 		    auto println = [&](auto name, auto backend, auto key_available, auto coherent) {
-			    printf("%-*s%s%-*s%s%-*s%s%-*s\n",                                         //
+			    printf("%-*s%s%-*s%s%-*s%s%s\n",                                           //
 			           static_cast<int>(max_name_len), name, separator,                    //
 			           static_cast<int>(max_backend_len), backend, separator,              //
 			           static_cast<int>(max_key_available_len), key_available, separator,  //
-			           static_cast<int>(max_coherent_len), coherent);
+			           coherent);
 		    };
 		    if(human)
-			    println("NAME", "BACK-END", "KEYSTATUS", "COHERENT");
+			    println(gettext("NAME"), gettext("BACK-END"), gettext("KEYSTATUS"), gettext("COHERENT"));
 		    for(auto cur = lines; cur != lines + lines_len; ++cur)
 			    if(cur->included(print_nontzpfms, backend_restrixion, key_loadedness_restrixion))
 				    println(cur->name, cur->backend_display(), output_line::key_available_display[cur->key_available], output_line::coherent_display[cur->coherent]);
