@@ -27,7 +27,7 @@ int main(int argc, char ** argv) {
 	uint32_t * pcrs{};
 	size_t pcrs_len{};
 	return do_main(
-	    argc, argv, "b:P:", "[-b backup-file] [-P PCR[,PCR]…]",
+	    argc, argv, "b:P:", gettext_noop("[-b backup-file] [-P PCR[,PCR]…]"),
 	    [&](auto o) {
 		    switch(o) {
 			    case 'b':
@@ -103,8 +103,9 @@ int main(int argc, char ** argv) {
 			    }};
 
 			    {
-				    char what_for[ZFS_MAX_DATASET_NAME_LEN + 40 + 1];
-				    snprintf(what_for, sizeof(what_for), "%s TPM1.X wrapping key (or empty for none)", zfs_get_name(dataset));
+				    char what_for[ZFS_MAX_DATASET_NAME_LEN + 512 + 1];
+				    // %s=dataset, then TPM1.X. noun for "Enter passphrase for" prompt
+				    snprintf(what_for, sizeof(what_for), gettext("%s %s wrapping key (or empty for none)"), zfs_get_name(dataset), THIS_BACKEND);
 
 				    uint8_t * parent_key_passphrase{};
 				    size_t parent_key_passphrase_len{};
