@@ -5,7 +5,6 @@
 // #include <sys/zio_crypt.h>
 #define WRAPPING_KEY_LEN 32
 
-#include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -59,15 +58,17 @@ int main(int argc, char ** argv) {
 			    TRY_TPM1X("load sealed object from blob", Tspi_SetAttribData(sealed_object, TSS_TSPATTRIB_ENCDATA_BLOB, TSS_TSPATTRIB_ENCDATABLOB_BLOB,
 			                                                                 handle.sealed_object_blob_len, handle.sealed_object_blob));
 
-			    char what_for[ZFS_MAX_DATASET_NAME_LEN + 20 + 1];
-			    snprintf(what_for, sizeof(what_for), "%s TPM1.X wrapping key", zfs_get_name(dataset));
+			    char what_for[ZFS_MAX_DATASET_NAME_LEN + 512 + 1];
+			    // %s=dataset name, then TPM1.x. noun for "Enter passphrase for" prompt
+			    snprintf(what_for, sizeof(what_for), gettext("%s %s wrapping key"), zfs_get_name(dataset), THIS_BACKEND);
 
 			    uint8_t * loaded_wrap_key{};
 			    uint32_t loaded_wrap_key_len{};
 			    TRY_MAIN(try_policy_or_passphrase("unseal wrapping key", what_for, parent_key_policy,
 			                                      [&] { return Tspi_Data_Unseal(sealed_object, parent_key, &loaded_wrap_key_len, &loaded_wrap_key); }));
 			    if(loaded_wrap_key_len != sizeof(wrap_key)) {
-				    fprintf(stderr, "Wrong sealed data length (%" PRIu32 " != %zu): ", loaded_wrap_key_len, sizeof(wrap_key));
+				    // 0A1234... follows
+				    fprintf(stderr, gettext("Wrong sealed data length (%u != %zu): "), loaded_wrap_key_len, sizeof(wrap_key));
 				    for(auto i = 0u; i < loaded_wrap_key_len; ++i)
 					    fprintf(stderr, "%02hhX", loaded_wrap_key[i]);
 				    fprintf(stderr, "\n");
