@@ -13,7 +13,7 @@
 	({                                                                                            \
 		auto _try_ret = (__VA_ARGS__);                                                              \
 		if(cond_pre _try_ret cond_post) {                                                           \
-			if constexpr(what != nullptr)                                                             \
+			if(what != nullptr)                                                                       \
 				fprintf(stderr, "Couldn't %s: %s\n", static_cast<const char *>(what), strerr(err_src)); \
 			return err_ret;                                                                           \
 		}                                                                                           \
@@ -30,4 +30,4 @@ struct quickscope_wrapper {
 };
 
 template <class F>
-quickscope_wrapper(F)->quickscope_wrapper<F>;
+quickscope_wrapper(F) -> quickscope_wrapper<F>;
