@@ -5,10 +5,13 @@
 
 
 #include "common.hpp"
+#include <libintl.h>
 #include <libzfs.h>
+#include <locale.h>
 #include <stdlib.h>
 #include <type_traits>
 #include <unistd.h>
+#define gettext_noop(s) s
 
 
 #define TRY_PTR(what, ...) TRY_GENERIC(what, !, , errno, __LINE__, strerror, __VA_ARGS__)
@@ -23,9 +26,12 @@ template <class G, class M, class V = int (*)()>
 static int do_bare_main(
     int argc, char ** argv, const char * getoptions, const char * usage, const char * dataset_usage, G && getoptfn, M && main,
     V && validate = []() { return 0; }) {
-	const auto libz = TRY_PTR("initialise libzfs", libzfs_init());
-	quickscope_wrapper libz_deleter{[=] { libzfs_fini(libz); }};
+	setlocale(LC_ALL, "");
+	bindtextdomain("tzpfms", "/usr/share/locale");
+	// bindtextdomain("tzpfms", "out/locale");
+	textdomain("tzpfms");
 
+	const auto libz = TRY_PTR("initialise libzfs", libzfs_init());
 	libzfs_print_on_error(libz, B_TRUE);
 
 	auto gopts = reinterpret_cast<char *>(alloca(strlen(getoptions) + 2 + 1));
@@ -35,7 +41,8 @@ static int do_bare_main(
 		switch(opt) {
 			case '?':
 			case 'h':
-				fprintf(opt == 'h' ? stdout : stderr, "Usage: %s [-hV] %s%s%s\n", argv[0], usage, strlen(usage) ? " " : "", dataset_usage);
+				fprintf(opt == 'h' ? stdout : stderr, gettext("usage: %s [-hV] %s%s%s\n"), argv[0], *usage ? gettext(usage) : "", *usage ? " " : "",
+				        gettext(dataset_usage));
 				return opt == 'h' ? 0 : __LINE__;
 			case 'V':
 				puts("tzpfms version " TZPFMS_VERSION);
@@ -47,29 +54,29 @@ static int do_bare_main(
 					TRY_MAIN(getoptfn(opt));
 				else {
 					if(auto err = getoptfn(opt))
-						return fprintf(stderr, "Usage: %s [-hV] %s%s%s\n", argv[0], usage, strlen(usage) ? " " : "", dataset_usage), err;
+						return fprintf(stderr, gettext("usage: %s [-hV] %s%s%s\n"), argv[0], *usage ? gettext(usage) : "", *usage ? " " : "", gettext(dataset_usage)), err;
 				}
 		}
 
 	if(auto err = validate())
-		return fprintf(stderr, "Usage: %s [-hV] %s%s%s\n", argv[0], usage, strlen(usage) ? " " : "", dataset_usage), err;
+		return fprintf(stderr, gettext("usage: %s [-hV] %s%s%s\n"), argv[0], *usage ? gettext(usage) : "", *usage ? " " : "", gettext(dataset_usage)), err;
 	return main(libz);
 }
 
 template <class G, class M, class V = int (*)()>
-static int do_main(
-    int argc, char ** argv, const char * getoptions, const char * usage, G && getoptfn, M && main, V && validate = []() { return 0; }) {
+static int do_main(int argc, char ** argv, const char * getoptions, const char * usage, G && getoptfn, M && main, V && validate = []() { return 0; }) {
 	return do_bare_main(
-	    argc, argv, getoptions, usage, "dataset", getoptfn,
+	    // as-in argument in a usage string
+	    argc, argv, getoptions, usage, gettext_noop("dataset"), getoptfn,
 	    [&](auto libz) {
 		    if(!*(argv + optind))
 			    return fprintf(stderr,
-			                   "No dataset to act on?\n"
-			                   "Usage: %s [-hV] %s%sdataset\n",
+			                   gettext("No dataset to act on?\n"
+			                           "usage: %s [-hV] %s%sdataset\n"),
 			                   argv[0], usage, strlen(usage) ? " " : ""),
 			           __LINE__;
 		    if(*(argv + optind + 1))
-			    return fprintf(stderr, "Usage: %s [-hV] %s%sdataset\n", argv[0], usage, strlen(usage) ? " " : ""), __LINE__;
+			    return fprintf(stderr, gettext("usage: %s [-hV] %s%sdataset\n"), argv[0], usage, strlen(usage) ? " " : ""), __LINE__;
 		    auto dataset = TRY_PTR(nullptr, zfs_open(libz, argv[optind], ZFS_TYPE_FILESYSTEM | ZFS_TYPE_VOLUME));
 		    quickscope_wrapper dataset_deleter{[&] { zfs_close(dataset); }};
 
@@ -79,9 +86,9 @@ static int do_main(
 			    TRY("get encryption root", zfs_crypto_get_encryption_root(dataset, &dataset_is_root, encryption_root));
 
 			    if(!dataset_is_root && !strlen(encryption_root))
-				    return fprintf(stderr, "Dataset %s not encrypted?\n", zfs_get_name(dataset)), __LINE__;
+				    return fprintf(stderr, gettext("Dataset %s not encrypted?\n"), zfs_get_name(dataset)), __LINE__;
 			    else if(!dataset_is_root) {
-				    fprintf(stderr, "Using dataset %s's encryption root %s instead.\n", zfs_get_name(dataset), encryption_root);
+				    fprintf(stderr, gettext("Using dataset %s's encryption root %s instead.\n"), zfs_get_name(dataset), encryption_root);
 				    zfs_close(dataset);
 				    dataset = TRY_PTR(nullptr, zfs_open(libz, encryption_root, ZFS_TYPE_FILESYSTEM | ZFS_TYPE_VOLUME));
 			    }
