@@ -10,10 +10,8 @@
 #include <string.h>
 
 
-// Funxion statics pull in libc++'s __cxa_guard_acquire()
-static nvlist_t * rrargs{};
-static quickscope_wrapper rrargs_deleter{[] { nvlist_free(rrargs); }};
 nvlist_t * rewrap_args() {
+	static nvlist_t * rrargs;
 	if(!rrargs)
 		if(auto err =
 		       [&] {
@@ -33,9 +31,8 @@ nvlist_t * rewrap_args() {
 }
 
 
-static nvlist_t * crrargs{};
-static quickscope_wrapper crrargs_deleter{[] { nvlist_free(crrargs); }};
 nvlist_t * clear_rewrap_args() {
+	static nvlist_t * crrargs;
 	if(!crrargs)
 		if(auto err =
 		       [&] {
@@ -98,8 +95,8 @@ int clear_key_props(zfs_handle_t * from) {
 	bool ok = false;
 	quickscope_wrapper props_deleter{[&] {
 		if(!ok)
-			fprintf(stderr, "You might need to run \"zfs inherit %s %s\" and \"zfs inherit %s %s\" to fully clear metadata!\n", PROPNAME_BACKEND, zfs_get_name(from),
-			        PROPNAME_KEY, zfs_get_name(from));
+			fprintf(stderr, gettext("You might need to run \"zfs inherit %s %s\" and \"zfs inherit %s %s\" to fully clear metadata!\n"), PROPNAME_BACKEND,
+			        zfs_get_name(from), PROPNAME_KEY, zfs_get_name(from));
 	}};
 
 	TRY("delete tzpfms.backend", zfs_prop_inherit(from, PROPNAME_BACKEND, B_FALSE));
@@ -113,13 +110,13 @@ int parse_key_props(zfs_handle_t * in, const char * our_backend, char *& handle)
 	TRY_MAIN(lookup_userprop(in, PROPNAME_BACKEND, backend));
 
 	if(!backend)
-		return fprintf(stderr, "Dataset %s not encrypted with tzpfms!\n", zfs_get_name(in)), __LINE__;
+		return fprintf(stderr, gettext("Dataset %s not encrypted with tzpfms!\n"), zfs_get_name(in)), __LINE__;
 	if(strcmp(backend, our_backend))
-		return fprintf(stderr, "Dataset %s encrypted with tzpfms back-end %s, but we are %s.\n", zfs_get_name(in), backend, our_backend), __LINE__;
+		return fprintf(stderr, gettext("Dataset %s encrypted with tzpfms back-end %s, but we are %s.\n"), zfs_get_name(in), backend, our_backend), __LINE__;
 
 	TRY_MAIN(lookup_userprop(in, PROPNAME_KEY, handle));
 	if(!handle)
-		return fprintf(stderr, "Dataset %s missing key data.\n", zfs_get_name(in)), __LINE__;
+		return fprintf(stderr, gettext("Dataset %s missing key data.\n"), zfs_get_name(in)), __LINE__;
 
 	return 0;
 }
