@@ -20,10 +20,10 @@
 
 
 /// Mimic libzfs error output
-#define REQUIRE_KEY_LOADED(dataset)                                                \
-	do {                                                                             \
-		if(zfs_prop_get_int(dataset, ZFS_PROP_KEYSTATUS) == ZFS_KEYSTATUS_UNAVAILABLE) \
-			return fprintf(stderr, "Key change error: Key must be loaded.\n"), __LINE__; \
+#define REQUIRE_KEY_LOADED(dataset)                                                         \
+	do {                                                                                      \
+		if(zfs_prop_get_int(dataset, ZFS_PROP_KEYSTATUS) == ZFS_KEYSTATUS_UNAVAILABLE)          \
+			return fprintf(stderr, gettext("Key change error: Key must be loaded.\n")), __LINE__; \
 	} while(0)
 
 
@@ -65,10 +65,14 @@ int verify_backend(zfs_handle_t * on, const char * this_backend, F && func) {
 	TRY_MAIN(lookup_userprop(on, PROPNAME_KEY, previous_handle));
 
 	if(!!previous_backend ^ !!previous_handle)
-		fprintf(stderr, "Inconsistent tzpfms metadata for %s: back-end is %s, but handle is %s?\n", zfs_get_name(on), previous_backend, previous_handle);
+		// dataset name: (null), 0A123...
+		// dataset name: TPM1.X, (null)
+		fprintf(stderr, gettext("Inconsistent tzpfms metadata for %s: back-end is %s, but handle is %s?\n"), zfs_get_name(on), previous_backend, previous_handle);
 	else if(previous_backend && previous_handle) {
 		if(strcmp(previous_backend, this_backend))
-			fprintf(stderr, "Dataset %s was encrypted with tzpfms back-end %s before, but we are %s. You will have to free handle %s for back-end %s manually!\n",
+			// dataset name: TPM1.X, TPM2. 0A1234..., TPM1.X
+			fprintf(stderr,
+			        gettext("Dataset %s was encrypted with tzpfms back-end %s before, but we are %s. You will have to free handle %s for back-end %s manually!\n"),
 			        zfs_get_name(on), previous_backend, this_backend, previous_handle, previous_backend);
 		else
 			func(previous_handle);
