@@ -30,7 +30,7 @@ int change_key(zfs_handle_t * on, const uint8_t * wrap_key) {
 		if(zfs_crypto_rewrap(on, TRY_PTR("get rewrap args", rewrap_args()), B_FALSE))
 			return __LINE__;  // Error printed by libzfs
 		else
-			printf("Key for %s changed\n", zfs_get_name(on));
+			printf(gettext("Key for %s changed\n"), zfs_get_name(on));
 
 		return 0;
 	});
@@ -41,8 +41,11 @@ int load_key(zfs_handle_t * for_d, const uint8_t * wrap_key, bool noop) {
 	return with_stdin_at_buffer(wrap_key, WRAPPING_KEY_LEN, [&] {
 		if(zfs_crypto_load_key(for_d, noop ? B_TRUE : B_FALSE, nullptr))
 			return __LINE__;  // Error printed by libzfs
-		else
-			printf("Key for %s %s\n", zfs_get_name(for_d), noop ? "OK" : "loaded");
+		else                //
+			if(noop)
+				printf(gettext("Key for %s OK\n"), zfs_get_name(for_d));
+			else
+				printf(gettext("Key for %s loaded\n"), zfs_get_name(for_d));
 
 		return 0;
 	});
